@@ -139,7 +139,7 @@ dfv.test=function(X.fdata,Y,B=5000,h=quantile(x=metric.lp(X.fdata),probs=c(0.05,
 	# Result: class htest
 	names(Tn)=paste("Tn(",sprintf("h=%.3f",h),")",sep="")
 	result=list(statistic=Tn,boot.statistics=Tn.star,p.value=pvalue,method="Delsol, Ferraty and Vieu test for no functional-scalar interaction",B=B,h=h,K=K,weights=weights,d=d,data.name="Y=0+e")
-	class(result)="htest"
+	class(result) <- "htest"
 	return(result)
 	
 }
