@@ -1,16 +1,12 @@
-#' Correlation for functional data by Principal Component Analysis
+#' @title Correlation for functional data by Principal Component Analysis
 #' 
-#' Compute correlation principal components of functional data and scalar
-#' response \code{y}. 
+#' @description Summary of functional principal components
 #' 
 #' @param object fdata.comp class object calculated by: \code{fdata2pc},
 #' \code{fdata2pls}, \code{fregre.pc} or \code{fregre.pls}.
-#' @param y (optional) The argument is only necessary if corplot=TRUE.
 #' @param biplot =TRUE draw the biplot and PC (or PLS) components.
-#' @param corplot =TRUE draw correlations between y and PC (or PLS) components.
 #' @param \dots Further arguments passed to or from other methods.
 #' @return If \code{corplot}=TRUE, are displaying the biplot between the PC (or PLS) components.\cr
-#'  If \code{corplot}=TRUE, are displaying the correlations between the PC (or PLS) components and response \code{y}.\cr 
 #'  If \code{ask}=TRUE, draw each graph in a window, waiting to confirm the change
 #' of page with a click of the mouse or pressing ENTER.  If \code{ask}=FALSE draw graphs in one window.
 #' @author Manuel Febrero-Bande and Manuel Oviedo de la Fuente \email{manuel.oviedo@@usc.es}
@@ -23,22 +19,22 @@
 #' @keywords multivariate
 #' @examples
 #' \dontrun{
-#' n= 200
-#' tt= seq(0,1,len=101)
-#' x0<-rproc2fdata(n,tt,sigma="wiener")
-#' x1<-rproc2fdata(n,tt,sigma=0.1)
-#' x<-x0*3+x1
-#' beta = tt*sin(2*pi*tt)^2
-#' fbeta = fdata(beta,tt)
-#' y<-inprod.fdata(x,fbeta)+rnorm(n,sd=0.1)
-#' pc1=fdata2pc(x)
-#' summary(pc1,y)
-#' pls1=fdata2pls(x,y)
-#' summary(pls1,cor=TRUE)
+#' n <- 200
+#' tt <- seq(0,1,len=101)
+#' x0 <- rproc2fdata(n,tt,sigma="wiener")
+#' x1 <- rproc2fdata(n,tt,sigma=0.1)
+#' x <- x0*3+x1
+#' beta <- tt*sin(2*pi*tt)^2
+#' fbeta <- fdata(beta,tt)
+#' y <- inprod.fdata(x,fbeta) + rnorm(n,sd=0.1)
+#' pc1 <- fdata2pc(x,3)
+#' summary(pc1)
+#' pls1 <- fdata2pls(x,y)
+#' summary(pls1)
 #' }
 #' 
 #' @export
-summary.fdata.comp=function(object,y=NULL,biplot=TRUE,corplot=FALSE,...) {
+summary.fdata.comp=function(object,biplot=TRUE,...) {
   if (inherits(object, "fdata.comp"))         {
      a1=TRUE
      pr.com<-object
@@ -51,7 +47,7 @@ summary.fdata.comp=function(object,y=NULL,biplot=TRUE,corplot=FALSE,...) {
      pr.com<-object$fdata.comp
      y<-object$y
   } else stop("Error in input data")
-  out2=pr.com$x
+ out2=pr.com$x
  l<-object$l
  le=length(l)
  rotation=aperm(pr.com$rotation$data)
@@ -67,38 +63,18 @@ summary.fdata.comp=function(object,y=NULL,biplot=TRUE,corplot=FALSE,...) {
  }
  C<-match.call()
  lenC=length(C)
- cor.y.pc=rep(NA,le)
- xxx=cbind(y,pr.com$x)
- cor.y.pc=round(cor(xxx[,c(1,l+1)]),3)[1,-1]
+ # cor.y.pc=rep(NA,le)
+ # xxx=cbind(y,pr.com$x)
+ # cor.y.pc=round(cor(xxx[,c(1,l+1)]),3)[1,-1]
  types<-colnames(pr.com$x)
  cat("\n     - SUMMARY:  ",object$call[[1]]," object   -\n")
- if (object$call[[1]]=="fdata2pc" | object$call[[1]]=="fdata2ppc") {
+ #if (object$call[[1]]=="fdata2pc" | object$call[[1]]=="fdata2ppc") 
+   {
    cat("\n-With",le," components are explained ",round(sum(pr.x2[l])*100
  ,2),"%\n of the variability of explicative variables.\n \n-Variability for each component (%):\n")
   # print(round(pr.x[l] * 100, 2))
   print(round(pr.x2[l] * 100, 2))
   }
-  if (corplot){
-   if (is.null(y)) stop("Argument y no introduced")
-   names(cor.y.pc)=paste("cor(y,",types[l],")",sep="")
-   cat("\n-Correlations:\n")
-   print(cor.y.pc)
-   j=1
-   dev.new()
-     while (j<=lenC) {
-       if (names(C)[j]=="ask") {ask=C[[j]];j=lenC +1}
-          else {j=j+1;ask=FALSE}
-     }
-     if (ask) {
-          par(mfrow=c(1,1))
-          dev.interactive()
-          oask <- devAskNewPage(TRUE)
-          on.exit(devAskNewPage(oask))
-          }
-     else   par(mfrow=c(ceiling(le/2),2))
-    for (i in 1:le)   plot(pr.com$x[,l[i]],y,main=paste("cor=",
-        round(cor.y.pc[i],3)),xlab=colnames(pr.com$x)[l[i]],ylab="y",...)
-  }
  if (biplot){
   j=1
   while (j<=lenC) {
@@ -108,7 +84,8 @@ summary.fdata.comp=function(object,y=NULL,biplot=TRUE,corplot=FALSE,...) {
            }
         else { j=j+1; ask=FALSE  }
   }
-   dev.new()
+   #dev.new()
+  
    if (ask) {
           par(mfrow=c(1,1))
           dev.interactive()
@@ -130,18 +107,22 @@ summary.fdata.comp=function(object,y=NULL,biplot=TRUE,corplot=FALSE,...) {
                            text(p[,c(l[j],i)])#,rownames(out2))
                }
            else  plot(p[,c(l[j],i)],main="BIPLOT")
-        } }  }
+      } }  
+    }
     else   {
-    par(mfrow=c(le,le))
+      par(mfrow=c(le,le))
+      for (kk in 1:(le*le)){
+        plot(0, xaxt = 'n', yaxt = 'n', bty = 'n', pch = '', ylab = '', xlab = '')
+      }
     for (i in 1:le) {
       par(mfg=c(i,i))
-      ts.plot(rotation[,l[i]],ylab=c("loadings",l[i],sep=""),
+      plot(rotation[,l[i]],ylab=c("loadings",l[i],sep=""),type="l",
        main=c(paste("Component",l[i],"- Expl. Var. ",round(pr.x2[l[i]] * 100, 2),"%",sep="")))
       if (i<le)
       for (j in (i+1):le) {
             par(mfg=c(i,j))
             if (nrow(out2)<50)     {
-                       plot(p[,c(i,l[j])],main="BIPLOT")
+                      plot(p[,c(i,l[j])],main="BIPLOT")
                       text(p[,c(i,l[j])])
                       }
             else plot(p[,c(i,l[j])],main="BIPLOT")
